@@ -57,25 +57,12 @@ class AbandonedReleaseError(exceptions.Error):
     super(AbandonedReleaseError, self).__init__(error_template)
 
 
-class MultipleSkaffoldSourcesError(exceptions.Error):
-  """Error when multiple sources are given for the Skaffold file."""
-
-  def __init__(self, from_k8s_manifest, skaffold_sources):
-    sources = (', '.join(skaffold_sources))
-    error_msg = (
-        'The --from-k8s-manifest={} flag and Skaffold file flag(s): {} were '
-        'given. This is invalid. When using the --from-k8s-manifest flag the '
-        'Skaffold file is generated for you. You do not need to provide '
-        'Skaffold file sources.').format(from_k8s_manifest, sources)
-    super(MultipleSkaffoldSourcesError, self).__init__(error_msg)
-
-
-class NoSnappedTargetsError(exceptions.Error):
-  """Error when a release doesn't contain any snapped target resource."""
+class NoStagesError(exceptions.Error):
+  """Error when a release doesn't contain any pipeline stages."""
 
   def __init__(self, release_name):
-    super(NoSnappedTargetsError, self).__init__(
-        'No snapped targets in the release {}.'.format(release_name))
+    super(NoStagesError, self).__init__(
+        'No pipeline stages in the release {}.'.format(release_name))
 
 
 class InvalidReleaseNameError(exceptions.Error):
@@ -101,6 +88,20 @@ class ListRolloutsError(exceptions.Error):
           self).__init__('Failed to list rollouts for {}.'.format(release_name))
 
 
+class RedeployRolloutError(exceptions.Error):
+  """Error when a rollout can't be redeployed.
+
+  Redeploy can only be used for rollouts that are in a SUCCEEDED or FAILED
+  state.
+  """
+
+  def __init__(self, target_name, rollout_name, rollout_state):
+    error_msg = (
+        'Unable to redeploy target {}. Rollout {} is in state {} that can\'t '
+        'be redeployed'.format(target_name, rollout_name, rollout_state))
+    super(RedeployRolloutError, self).__init__(error_msg)
+
+
 class RolloutIDExhaustedError(exceptions.Error):
   """Error when there are too many rollouts for a given release."""
 
