@@ -15,7 +15,6 @@
 
 """Data objects to support the yaml command schema."""
 
-
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
@@ -27,7 +26,6 @@ from googlecloudsdk.command_lib.util.apis import arg_utils
 from googlecloudsdk.command_lib.util.apis import resource_arg_schema
 from googlecloudsdk.command_lib.util.apis import yaml_command_schema_util as util
 
-
 NAME_FORMAT_KEY = '__name__'
 REL_NAME_FORMAT_KEY = '__relative_name__'
 RESOURCE_TYPE_FORMAT_KEY = '__resource_type__'
@@ -43,9 +41,12 @@ class CommandData(object):
     ]
     self.command_type = CommandType.ForName(data.get('command_type', name))
     self.help_text = data['help_text']
-    request_data = data.get('request')
-    self.request = Request(self.command_type, request_data)
-    self.response = Response(data.get('response', {}))
+    self.request = None
+    self.response = None
+    if CommandType.HasRequestMethod(self.command_type):
+      request_data = data.get('request')
+      self.request = Request(self.command_type, request_data)
+      self.response = Response(data.get('response', {}))
     async_data = data.get('async')
     iam_data = data.get('iam')
     update_data = data.get('update')
@@ -65,36 +66,26 @@ class CommandData(object):
 
 
 class CommandType(Enum):
-  """An enum for the types of commands the generator supports.
+  """An enum for the types of commands the generator supports."""
+  DESCRIBE = 1
+  LIST = 2
+  DELETE = 3
+  IMPORT = 4
+  EXPORT = 5
+  CONFIG_EXPORT = 6
+  CREATE = 7
+  WAIT = 8
+  UPDATE = 9
+  GET_IAM_POLICY = 10
+  SET_IAM_POLICY = 11
+  ADD_IAM_POLICY_BINDING = 12
+  REMOVE_IAM_POLICY_BINDING = 13
+  GENERIC = 14
 
-  Attributes:
-    default_method: str, The name of the API method to use by default for this
-      type of command.
-  """
-  DESCRIBE = 'get'
-  LIST = 'list'
-  DELETE = 'delete'
-  IMPORT = 'patch'
-  EXPORT = 'get'
-  CREATE = 'create'
-  WAIT = 'get'
-  UPDATE = 'patch'
-  # IAM support currently implemented as subcommands
-  GET_IAM_POLICY = 'getIamPolicy'
-  SET_IAM_POLICY = 'setIamPolicy'
-  # For add/remove-iam-policy-binding commands, the actual API method to modify
-  # the iam support is 'setIamPolicy'.
-  ADD_IAM_POLICY_BINDING = 'setIamPolicy'
-  REMOVE_IAM_POLICY_BINDING = 'setIamPolicy'
-  # Generic commands are those that don't extend a specific calliope command
-  # base class.
-  GENERIC = None
-
-  def __init__(self, default_method):
-    # Set the value to a unique object so multiple enums can have the same
-    # default method.
-    self._value_ = object()
-    self.default_method = default_method
+  @property
+  def default_method(self):
+    """Returns the default API method name for this type of command."""
+    return _DEFAULT_METHODS_BY_COMMAND_TYPE.get(self)
 
   @classmethod
   def ForName(cls, name):
@@ -103,6 +94,34 @@ class CommandType(Enum):
     except KeyError:
       return CommandType.GENERIC
 
+  @classmethod
+  def HasRequestMethod(cls, name):
+    methodless_commands = {cls.CONFIG_EXPORT}
+    return name not in methodless_commands
+
+
+_DEFAULT_METHODS_BY_COMMAND_TYPE = {
+    CommandType.DESCRIBE: 'get',
+    CommandType.LIST: 'list',
+    CommandType.DELETE: 'delete',
+    CommandType.IMPORT: 'patch',
+    CommandType.EXPORT: 'get',
+    CommandType.CONFIG_EXPORT: 'config_export',
+    CommandType.CREATE: 'create',
+    CommandType.WAIT: 'get',
+    CommandType.UPDATE: 'patch',
+    # IAM support currently implemented as subcommands
+    CommandType.GET_IAM_POLICY: 'getIamPolicy',
+    CommandType.SET_IAM_POLICY: 'setIamPolicy',
+    # For add/remove-iam-policy-binding commands, the actual API method to
+    # modify the iam support is 'setIamPolicy'.
+    CommandType.ADD_IAM_POLICY_BINDING: 'setIamPolicy',
+    CommandType.REMOVE_IAM_POLICY_BINDING: 'setIamPolicy',
+    # Generic commands are those that don't extend a specific calliope command
+    # base class.
+    CommandType.GENERIC: None,
+}
+
 
 class Request(object):
   """A holder object for api request information specified in yaml command."""
@@ -350,7 +369,7 @@ class Argument(object):
     self.repeated = repeated
     self.generate = generate
 
-  def Generate(self, message):
+  def Generate(self, message=None):
     """Generates and returns the base argument.
 
     Args:
@@ -359,7 +378,7 @@ class Argument(object):
     Returns:
       The base argument.
     """
-    if self.api_field:
+    if message and self.api_field:
       field = arg_utils.GetFieldFromMessage(message, self.api_field)
     else:
       field = None
