@@ -69,6 +69,7 @@ class Create(base.CreateCommand):
   _support_confidential_compute_type = True
   _support_provisioned_throughput = True
   _support_no_address_in_networking = True
+  _support_max_count_per_zone = False
 
   @classmethod
   def Args(cls, parser):
@@ -88,10 +89,11 @@ class Create(base.CreateCommand):
         support_max_run_duration=cls._support_max_run_duration,
         support_enable_target_shape=cls._support_enable_target_shape,
         add_zone_region_flags=False,
-        support_confidential_compute_type=cls
-        ._support_confidential_compute_type,
+        support_confidential_compute_type=cls._support_confidential_compute_type,
         support_provisioned_throughput=cls._support_provisioned_throughput,
-        support_no_address_in_networking=cls._support_no_address_in_networking)
+        support_no_address_in_networking=cls._support_no_address_in_networking,
+        support_max_count_per_zone=cls._support_max_count_per_zone,
+    )
     cls.AddSourceInstanceTemplate(parser)
     instances_flags.AddSecureTagsArgs(parser)
     instances_flags.AddHostErrorTimeoutSecondsArgs(parser)
@@ -127,7 +129,9 @@ class Create(base.CreateCommand):
         support_enable_target_shape=self._support_enable_target_shape,
         support_max_run_duration=self._support_max_run_duration,
         support_image_csek=self._support_image_csek,
-        support_source_snapshot_csek=self._support_source_snapshot_csek)
+        support_source_snapshot_csek=self._support_source_snapshot_csek,
+        support_max_count_per_zone=self._support_max_count_per_zone,
+    )
 
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
     client = holder.client
@@ -142,17 +146,29 @@ class Create(base.CreateCommand):
       zone = queued_resource_ref.zone
 
     supported_features = bulk_util.SupportedFeatures(
-        self._support_nvdimm, self._support_public_dns, self._support_erase_vss,
-        self._support_min_node_cpu, self._support_source_snapshot_csek,
-        self._support_image_csek, self._support_confidential_compute,
+        self._support_nvdimm,
+        self._support_public_dns,
+        self._support_erase_vss,
+        self._support_min_node_cpu,
+        self._support_source_snapshot_csek,
+        self._support_image_csek,
+        self._support_confidential_compute,
         self._support_post_key_revocation_action_type,
-        self._support_rsa_encrypted, self._deprecate_maintenance_policy,
-        self._support_create_disk_snapshots, self._support_boot_snapshot_uri,
-        self._support_display_device, self._support_local_ssd_size,
-        self._support_secure_tags, self._support_host_error_timeout_seconds,
-        self._support_numa_node_count, self._support_visible_core_count,
-        self._support_max_run_duration, self._support_enable_target_shape,
-        self._support_confidential_compute_type)
+        self._support_rsa_encrypted,
+        self._deprecate_maintenance_policy,
+        self._support_create_disk_snapshots,
+        self._support_boot_snapshot_uri,
+        self._support_display_device,
+        self._support_local_ssd_size,
+        self._support_secure_tags,
+        self._support_host_error_timeout_seconds,
+        self._support_numa_node_count,
+        self._support_visible_core_count,
+        self._support_max_run_duration,
+        self._support_enable_target_shape,
+        self._support_confidential_compute_type,
+        self._support_max_count_per_zone,
+    )
     bulk_insert_instance_resource = bulk_util.CreateBulkInsertInstanceResource(
         args, holder, client, holder.resources, queued_resource_ref.project,
         zone, compute_scopes.ScopeEnum.ZONE, self.SOURCE_INSTANCE_TEMPLATE,
