@@ -346,8 +346,9 @@ class Update(base.UpdateCommand):
     flags.AddEnablePrivateEndpoint(group)
     flags.AddEnableGoogleCloudAccess(group)
     flags.AddLoggingVariantFlag(group)
-    flags.AddAdditionalPodIpv4RangesFlag(group)
-    flags.AddRemoveAdditionalPodIpv4RangesFlag(group)
+    group_add_pod_ipv4_ranges = group.add_group(hidden=True)
+    flags.AddAdditionalPodIpv4RangesFlag(group_add_pod_ipv4_ranges)
+    flags.AddRemoveAdditionalPodIpv4RangesFlag(group_add_pod_ipv4_ranges)
     flags.AddStackTypeFlag(group)
     flags.AddCostManagementConfigFlag(group, is_update=True)
     flags.AddGatewayFlags(group, hidden=False)
@@ -818,8 +819,9 @@ class UpdateBeta(Update):
     flags.AddCostManagementConfigFlag(group, is_update=True)
     flags.AddStackTypeFlag(group)
     flags.AddLoggingVariantFlag(group)
-    flags.AddAdditionalPodIpv4RangesFlag(group)
-    flags.AddRemoveAdditionalPodIpv4RangesFlag(group)
+    group_add_pod_ipv4_ranges = group.add_group(hidden=True)
+    flags.AddAdditionalPodIpv4RangesFlag(group_add_pod_ipv4_ranges)
+    flags.AddRemoveAdditionalPodIpv4RangesFlag(group_add_pod_ipv4_ranges)
     flags.AddGatewayFlags(group, hidden=False)
     flags.AddFleetProjectFlag(group, is_update=True)
 
@@ -1010,8 +1012,9 @@ class UpdateAlpha(Update):
     flags.AddStackTypeFlag(group)
     flags.AddGatewayFlags(group, hidden=False)
     flags.AddLoggingVariantFlag(group)
-    flags.AddAdditionalPodIpv4RangesFlag(group)
-    flags.AddRemoveAdditionalPodIpv4RangesFlag(group)
+    group_add_pod_ipv4_ranges = group.add_group(hidden=True)
+    flags.AddAdditionalPodIpv4RangesFlag(group_add_pod_ipv4_ranges)
+    flags.AddRemoveAdditionalPodIpv4RangesFlag(group_add_pod_ipv4_ranges)
     flags.AddFleetProjectFlag(group, is_update=True)
 
   def ParseUpdateOptions(self, args, locations):
